@@ -1,9 +1,9 @@
 package WordList::Test::Dynamic::OneTwo_Each;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-28'; # DATE
+our $DATE = '2021-02-23'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.7'; # VERSION
+our $VERSION = '0.7.8'; # VERSION
 
 use strict;
 
@@ -26,7 +26,7 @@ sub each_word {
     }
 }
 
-our %STATS = ("num_words_contains_whitespace",0,"longest_word_len",3,"avg_word_len",3,"num_words_contains_unicode",0,"num_words_contain_whitespace",0,"num_words_contain_unicode",0,"num_words",2,"shortest_word_len",3,"num_words_contains_nonword_chars",0,"num_words_contain_nonword_chars",0); # STATS
+our %STATS = ("num_words_contain_unicode",0,"shortest_word_len",3,"num_words_contains_whitespace",0,"longest_word_len",3,"avg_word_len",3,"num_words",2,"num_words_contain_whitespace",0,"num_words_contains_unicode",0,"num_words_contains_nonword_chars",0,"num_words_contain_nonword_chars",0); # STATS
 
 1;
 # ABSTRACT: Wordlist that returns one, two (via implementing each_word())
@@ -43,7 +43,7 @@ WordList::Test::Dynamic::OneTwo_Each - Wordlist that returns one, two (via imple
 
 =head1 VERSION
 
-This document describes version 0.7.7 of WordList::Test::Dynamic::OneTwo_Each (from Perl distribution WordList), released on 2021-01-28.
+This document describes version 0.7.8 of WordList::Test::Dynamic::OneTwo_Each (from Perl distribution WordList), released on 2021-02-23.
 
 =head1 SYNOPSIS
 
