@@ -1,9 +1,9 @@
 package WordListRole::FirstNextResetFromEach;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-28'; # DATE
+our $DATE = '2021-02-23'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.7'; # VERSION
+our $VERSION = '0.7.8'; # VERSION
 
 use Role::Tiny;
 
@@ -51,7 +51,7 @@ WordListRole::FirstNextResetFromEach - Provide first_word(), next_word(), reset_
 
 =head1 VERSION
 
-This document describes version 0.7.7 of WordListRole::FirstNextResetFromEach (from Perl distribution WordList), released on 2021-01-28.
+This document describes version 0.7.8 of WordListRole::FirstNextResetFromEach (from Perl distribution WordList), released on 2021-02-23.
 
 =head1 DESCRIPTION
 
@@ -61,6 +61,18 @@ C<next_word()>, C<reset_iterator()> that uses C<each_word()>.
 
 =for Pod::Coverage .+
 
+=head1 REQUIRED METHODS
+
+=head2 each_word
+
+=head1 PROVIDED METHODS
+
+=head2 first_word
+
+=head2 next_word
+
+=head2 reset_iterator
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/WordList>.
@@ -77,6 +89,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<WordListRole::EachFromFirstNextReset>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
